@@ -51,15 +51,18 @@ namespace SDDM {
     };
 
     UserModel::UserModel(QObject *parent) : QAbstractListModel(parent), d(new UserModelPrivate()) {
+        const QString facesDir = mainConfig.Theme.FacesDir.get();
+        const QString defaultFace = QStringLiteral("file://%1/.face.icon").arg(facesDir);
+
         struct passwd *current_pw;
         while ((current_pw = getpwent()) != nullptr) {
 
             // skip entries with uids smaller than minimum uid
-            if ( int(current_pw->pw_uid) < mainConfig.Users.MinimumUid.get())
+            if (int(current_pw->pw_uid) < mainConfig.Users.MinimumUid.get())
                 continue;
 
             // skip entries with uids greater than maximum uid
-            if ( int(current_pw->pw_uid) > mainConfig.Users.MaximumUid.get())
+            if (int(current_pw->pw_uid) > mainConfig.Users.MaximumUid.get())
                 continue;
             // skip entries with user names in the hide users list
             if (mainConfig.Users.HideUsers.get().contains(QString::fromLocal8Bit(current_pw->pw_name)))
@@ -69,6 +72,13 @@ namespace SDDM {
             if (mainConfig.Users.HideShells.get().contains(QString::fromLocal8Bit(current_pw->pw_shell)))
                 continue;
 
+            // skip duplicates
+            // Note: getpwent() makes no attempt to suppress duplicate information
+            // if multiple sources are specified in nsswitch.conf(5).
+            if (d->users.cend()
+                != std::find_if(d->users.cbegin(), d->users.cend(), [current_pw](const UserPtr & u) { return u->uid == current_pw->pw_uid; }))
+                continue;
+
             // create user
             UserPtr user { new User() };
             user->name = QString::fromLocal8Bit(current_pw->pw_name);
@@ -81,14 +91,7 @@ namespace SDDM {
             user->needsPassword = strcmp(current_pw->pw_passwd, "") != 0;
 
             // search for face icon
-            QString userFace = QStringLiteral("%1/.face.icon").arg(user->homeDir);
-            QString systemFace = QStringLiteral("%1/%2.face.icon").arg(mainConfig.Theme.FacesDir.get()).arg(user->name);
-            if (QFile::exists(userFace))
-                user->icon = userFace;
-            else if (QFile::exists(systemFace))
-                user->icon = systemFace;
-            else
-                user->icon = QStringLiteral("%1/default.face.icon").arg(mainConfig.Theme.FacesDir.get());
+            user->icon = defaultFace;
 
             // add user
             d->users << user;
@@ -99,10 +102,26 @@ namespace SDDM {
         // sort users by username
         std::sort(d->users.begin(), d->users.end(), [&](const UserPtr &u1, const UserPtr &u2) { return u1->name < u2->name; });
 
+        bool avatarsEnabled = mainConfig.Theme.EnableAvatars.get();
+        if (avatarsEnabled && mainConfig.Theme.EnableAvatars.isDefault()) {
+            if (d->users.count() > mainConfig.Theme.DisableAvatarsThreshold.get()) avatarsEnabled=false;
+        }
+
         // find out index of the last user
         for (int i = 0; i < d->users.size(); ++i) {
-            if (d->users.at(i)->name == stateConfig.Last.User.get())
+            UserPtr user { d->users.at(i) };
+            if (user->name == stateConfig.Last.User.get())
                 d->lastIndex = i;
+
+            if (avatarsEnabled) {
+                const QString userFace = QStringLiteral("%1/.face.icon").arg(user->homeDir);
+                const QString systemFace = QStringLiteral("%1/%2.face.icon").arg(facesDir).arg(user->name);
+
+                if (QFile::exists(userFace))
+                    user->icon = QStringLiteral("file://%1").arg(userFace);
+                else if (QFile::exists(systemFace))
+                    user->icon = QStringLiteral("file://%1").arg(systemFace);
+            }
         }
     }
 
@@ -156,4 +175,8 @@ namespace SDDM {
         // return empty value
         return QVariant();
     }
+
+    int UserModel::disableAvatarsThreshold() const {
+        return mainConfig.Theme.DisableAvatarsThreshold.get();
+    }
 }
